RedMab
======
*RedMab: Multi-Armed Bandit Experiments backed by Redis in python*

|BuildStatus| |CoverageStatus| |Version| |Python| |Docs|


Requirements
------------

The *redmab* package requires Python 2.7 or higher.


Installation
------------

To install, use pip:

.. code-block::

    $ pip install redmab

or from source:

.. code-block::

    $ python setup.py install



Documentation
-------------
Find **RedMab** documentation on `Read the Docs <http://redmab.readthedocs.io/en/latest/>`_.


.. |BuildStatus| image:: https://travis-ci.org/72squared/redmab.svg?branch=master
    :target: https://travis-ci.org/72squared/redmab

.. |CoverageStatus| image:: https://coveralls.io/repos/github/72squared/redmab/badge.svg?branch=master
    :target: https://coveralls.io/github/72squared/redmab?branch=master

.. |Version| image:: https://badge.fury.io/py/redmab.svg
    :target: https://badge.fury.io/py/redmab

.. |Python| image:: https://img.shields.io/badge/python-2.7,3.4,pypy-blue.svg
    :target:  https://pypi.python.org/pypi/redmab/

.. |Docs| image:: https://readthedocs.org/projects/redmab/badge/?version=latest
    :target: http://redmab.readthedocs.org/en/latest/
    :alt: Documentation Status
